@@ -52,14 +52,21 @@ def CreateRecordFile():
     #create file, write header
     d=strftime("%Y-%m-%d_%H-%M-%S", records.StartTime_tuple)
     data.RecordFilename="SleepAnalyser_"+d+".csv"
-    data.RecordFile = open(data.RecordFolder+data.RecordFilename, 'w')
+    try:
+        data.RecordFile = open(data.RecordFolder+data.RecordFilename, 'w')
+    except:
+        print "ERROR! Can not open file for write access"
+        Notify(_("Can not create record file! File system might be read only"))
+        return 1
+
+
     print "Created RecordFile "+data.RecordFilename
 
     h=CreateHeader()
     data.RecordFile.write(h)
     data.RecordFile.flush()
 
-
+    return 0
 
 
 
@@ -448,7 +455,14 @@ def LoadRecord():
 ## Returns:     none
 ###########################################################################
 def UpdateFileHeader():
-    file = open(data.RecordFolder+data.RecordFilename, 'w')
+    try:
+        file = open(data.RecordFolder+data.RecordFilename, 'w')
+    except: #can not open, might be read only file system
+        print "ERROR! Can not open file for write access"
+        Notify(_("Can not update the data! File system might be read only"))
+        return
+
+
     print "Update header in RecordFile", data.RecordFilename
 
     h=CreateHeader()
