@@ -562,6 +562,17 @@ def getFileList(path,  filter):
     #Note: Above command could also be implemented with os.listdir(). This might give a minor speed improvement
     arr=output.split("\n")
     arr.pop()
+    
+    print "Check if file/folder does not contain % or ,"
+    i=len(arr)-1
+    while(i>=0):
+#        print i
+        if(string.find(arr[i],  "%")!=-1 or string.find(arr[i],  ",")!=-1):
+            print "Remove file",  arr[i],  "from list, name contaions illegal characters"
+            arr.pop(i)
+        i=i-1
+    
+#    print arr
     print len(arr), "files ("+filter+") in", path
     return arr
 
